@@ -13,7 +13,7 @@ L<Gearman::Driver> works with L<Gearman::XS> as well as with the pure
 Perl modules L<Gearman> and L<Gearman::Server>. By default it tries
 to use L<Gearman::XS>. If that fails L<Gearman> is used. You can
 also export an environment variable C<GEARMAN_DRIVER_ADAPTOR> to
-force usage of L<Gearman> even if you have L<Gearman::XS>.
+force usage of L<Gearman> even if you have L<Gearman::XS> installed.
 
 Example:
 
@@ -49,24 +49,14 @@ has 'server' => (
 sub _build_backend {
     my ($self) = @_;
 
-    my @classes = qw(Gearman::Driver::Adaptor::XS Gearman::Driver::Adaptor::PP);
-
-    unshift @classes, $ENV{GEARMAN_DRIVER_ADAPTOR} if defined $ENV{GEARMAN_DRIVER_ADAPTOR};
-
-    foreach my $class (@classes) {
-        eval "require $class";
-        unless ($@) {
-            warn sprintf "using adaptor: %s\n", $class
-              if ( $ENV{AUTOMATED_TESTING} );
-            return $class->new( server => $self->server );
-        }
-        else {
-            warn sprintf "Could not load class: %s (%s)\n", $class, $@
-              if ( $ENV{AUTOMATED_TESTING} );
-        }
+    my $class = $ENV{GEARMAN_DRIVER_ADAPTOR} || 'Gearman::Driver::Adaptor::XS';
+    eval "require $class;";
+    unless ($@) {
+        return $class->new( server => $self->server );
     }
 
-    die "None of the supported adaptors could be loaded: %s\n", join ', ', @classes;
+    Class::MOP::load_class('Gearman::Driver::Adaptor::PP');
+    return Gearman::Driver::Adaptor::PP->new( server => $self->server );
 }
 
 sub BUILD {
@@ -96,8 +86,6 @@ See L<Gearman::Driver>.
 
 =item * L<Gearman::Driver::Job>
 
-=item * L<Gearman::Driver::Job::Method>
-
 =item * L<Gearman::Driver::Loader>
 
 =item * L<Gearman::Driver::Observer>
@@ -110,4 +98,5 @@ See L<Gearman::Driver>.
 
 =cut
 
+
 1;
